import * as React from 'react';

import { 
  Remove as RemoveIcon,
  Add as AddIcon
} from '@mui/icons-material';

import {
  Card,CardContent,Avatar,Checkbox,List,Tooltip,
  ListItem,ListItemButton,ListItemIcon,ListItemText
} from '@mui/material'

import { deepPurple } from '@mui/material/colors';

function CheckboxexHeader(prop) {
  return (
    <List sx={{ width: '100%', bgcolor: 'background.paper' }}>
      <ListItem>
        <Avatar sx={{ bgcolor: deepPurple[500] }}>{prop.group}</Avatar>
        <ListItemButton role={undefined} dense>
          <ListItemText style={{marginRight :25, color:'silver'}} primary={prop.title} />
          <ListItemIcon>
            <AddIcon />
          </ListItemIcon>
          <ListItemIcon>
            <RemoveIcon />
          </ListItemIcon>
        </ListItemButton>
      </ListItem>
    </List>
  );
}

function CheckboxesGroup(props) {

  const [checked, setChecked] = React.useState([0]);

  const handleToggle = (value) => () => {

    const currentIndex = checked.indexOf(value);
    const newChecked = [...checked];
    if (currentIndex === -1) {
      newChecked.push(value);
    } else {
      newChecked.splice(currentIndex, 1);
    }

    setChecked(newChecked);
  };

  return (
    <List sx={{ width: '100%', bgcolor: 'background.paper' }}>
      {props.quiz.map((value) => {
        const labelId = `checkbox-list-label-${value.id}`;
        return (
          <ListItem key={value.id}>
            <ListItemButton role={undefined} onClick={handleToggle(value)} dense>
              <Tooltip title={value.decription} placement="top-start" arrow>
                <ListItemText 
                  sx={{ '& .MuiTypography-root' : {
                      fontWeight:'bold'
                  }}} className="checkbox_label_question" id={labelId} primary={value.nombre} />
              </Tooltip>

              <ListItemIcon>
                <Checkbox
                  edge="start"
                  checked={checked.indexOf(value) !== -1}
                  tabIndex={-1}
                  disableRipple
                  inputProps={{ 'aria-labelledby': labelId }}
                />
              </ListItemIcon>
              <ListItemIcon>
                <Checkbox
                  edge="start"
                  //checked={}
                  tabIndex={-1}
                  disableRipple
                  inputProps={{ 'aria-labelledby': labelId }}
                />
              </ListItemIcon>
            </ListItemButton>
          </ListItem>
        );
      })}
    </List>
  );
}

export function Question({ quiz}) {
  let { instrucciondepregunta, respuestas,id } = quiz
  return (
    <Card sx={{ minWidth: 275, margin: '30px !important', borderLeft: '5px solid var(--main)'}}>
      <CardContent>

        <div variant="body2">
          <List>
            <CheckboxexHeader  group={id} title={instrucciondepregunta}/>
          </List>
          <CheckboxesGroup quiz={respuestas} />
        </div>
      </CardContent>
    </Card>
  );
}
